Documentation
¶
Index ¶
- Constants
- Variables
- func BuildEphemeralReports(ephr, cephr rest.Storage) genericapiserver.APIGroupInfo
- func BuildOpenreports(rep, crep rest.Storage) genericapiserver.APIGroupInfo
- func BuildPolicyReports(polr, cpolr rest.Storage) genericapiserver.APIGroupInfo
- func DefaultSubsetNegotiatedSerializer(codecs serializer.CodecFactory) runtime.NegotiatedSerializer
- func Install(store api.Storage, server *genericapiserver.GenericAPIServer) error
- func NoProtobuf(info runtime.SerializerInfo) bool
- func RegisterAPIMetrics(registrationFunc func(metrics.Registerable) error) error
- func SubsetNegotiatedSerializer(codecs serializer.CodecFactory, ...) runtime.NegotiatedSerializer
- type API
- func ClusterEphemeralReportStore(store storageapi.GenericClusterIface[*reportsv1.ClusterEphemeralReport]) API
- func ClusterPolicyReportStore(store api.GenericClusterIface[*v1alpha2.ClusterPolicyReport]) API
- func ClusterReportStore(store storageapi.GenericClusterIface[*openreportsv1alpha1.ClusterReport]) API
- func EphemeralReportStore(store storageapi.GenericIface[*reportsv1.EphemeralReport]) API
- func PolicyReportStore(store storageapi.GenericIface[*v1alpha2.PolicyReport]) API
- func ReportStore(store storageapi.GenericIface[*openreportsv1alpha1.Report]) API
Constants ¶
const ( ServedByReportsServerAnnotation = "kyverno.reports-server.io/served-by" ServedByReportsServerValue = "reports-server" )
Variables ¶
var ( // Scheme contains the types needed by the resource API. Scheme = newScheme() // Codecs is a codec factory for serving the resource API. Codecs = serializer.NewCodecFactory(Scheme) )
Functions ¶
func BuildEphemeralReports ¶
func BuildEphemeralReports(ephr, cephr rest.Storage) genericapiserver.APIGroupInfo
BuildEphemeralReports constructs APIGroupInfo the reports.kyverno.io API group using the given getters.
func BuildOpenreports ¶ added in v0.1.5
func BuildOpenreports(rep, crep rest.Storage) genericapiserver.APIGroupInfo
BuildOpenreports constructs APIGroupInfo the openreports.io API group using the given getters.
func BuildPolicyReports ¶
func BuildPolicyReports(polr, cpolr rest.Storage) genericapiserver.APIGroupInfo
BuildPolicyReports constructs APIGroupInfo the wgpolicyk8s.io API group using the given getters.
func DefaultSubsetNegotiatedSerializer ¶
func DefaultSubsetNegotiatedSerializer(codecs serializer.CodecFactory) runtime.NegotiatedSerializer
func Install ¶
func Install(store api.Storage, server *genericapiserver.GenericAPIServer) error
Install builds the reports for the wgpolicyk8s.io, openreports.io and reports.kyverno.io API, and then installs it into the given API reports-server.
func NoProtobuf ¶
func NoProtobuf(info runtime.SerializerInfo) bool
func RegisterAPIMetrics ¶
func RegisterAPIMetrics(registrationFunc func(metrics.Registerable) error) error
func SubsetNegotiatedSerializer ¶
func SubsetNegotiatedSerializer(codecs serializer.CodecFactory, accepts ...func(info runtime.SerializerInfo) bool) runtime.NegotiatedSerializer
Types ¶
type API ¶
type API interface {
rest.Storage
rest.KindProvider
rest.Scoper
rest.SingularNameProvider
rest.StandardStorage
rest.ShortNamesProvider
}
func ClusterEphemeralReportStore ¶
func ClusterEphemeralReportStore(store storageapi.GenericClusterIface[*reportsv1.ClusterEphemeralReport]) API
func ClusterPolicyReportStore ¶
func ClusterPolicyReportStore(store api.GenericClusterIface[*v1alpha2.ClusterPolicyReport]) API
func ClusterReportStore ¶ added in v0.1.5
func ClusterReportStore(store storageapi.GenericClusterIface[*openreportsv1alpha1.ClusterReport]) API
func EphemeralReportStore ¶
func EphemeralReportStore(store storageapi.GenericIface[*reportsv1.EphemeralReport]) API
func PolicyReportStore ¶
func PolicyReportStore(store storageapi.GenericIface[*v1alpha2.PolicyReport]) API
func ReportStore ¶ added in v0.1.5
func ReportStore(store storageapi.GenericIface[*openreportsv1alpha1.Report]) API
Source Files
¶
Click to show internal directories.
Click to hide internal directories.